@@ -9,14 +9,22 @@ sub close_connections
 {
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 OpenERP::OOM::Link::Provider
 
-=head1 DESCRIPTION
+=head1 VERSION
 
-This is the role for a link provider that provides a way to link another dataset,
-normally a DBIC dataset.
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -42,6 +50,15 @@ normally a DBIC dataset.
 
     1;
 
+=head1 DESCRIPTION
+
+This is the role for a link provider that provides a way to link another dataset,
+normally a DBIC dataset.
+
+=head1 NAME
+
+OpenERP::OOM::Link::Provider
+
 =head1 METHODS
 
 =head2 close_connections
@@ -54,6 +71,15 @@ Copyright (C) 2011 OpusVL
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-=cut
+=head1 AUTHOR
 
-1;
+Jon Allen (JJ), <jj@opusvl.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011-2016 by OpusVL.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
