@@ -1,87 +1,5 @@
 package OpenERP::OOM::Object;
 
-=head1 NAME
-
-OpenERP::OOM::Object
-
-=head1 SYNOPSIS
-
-    package Package::OpenERP::Object::Account;
-
-    use 5.010;
-    use OpenERP::OOM::Object;
-
-    openerp_model 'account.account';
-
-    has active => (is => 'rw', isa => 'Bool'); # Active
-    has code => (is => 'rw', isa => 'Str'); # (required) Code
-
-    ...
-
-    relationship 'consolidated_children' => (
-        key   => 'child_consol_ids',
-        type  => 'many2many',
-        class => 'Account',
-    ); # Consolidated Children
-
-    ...
-
-    1;
-
-=head1 DESCRIPTION
-
-Use this module to create the 'objects' for your models.  It also implicitly loads
-Moose too.  
-
-The class is linked to a model in OpenERP.
-
-=head1 METHODS
-
-=head2 openerp_model
-
-Specify the model in OpenERP.
-
-=head2 init_meta
-
-An internal method that hooks up the Moose internals and implicitly makes your
-new classes inherit from OpenERP::OOM::Object::Base.  See the 
-OpenERP::OOM::Object::Base documentation for a list of the methods your objects
-will have by default.
-
-=head2 relationship
-
-Used to specify relationships between this object and others in OpenERP.
-
-Possible options for the type are many2one, one2many and many2many.  These
-are specified in OpenERP in those terms.
-
-=head2 has_link
-
-Used to indicate links with other systems.  Typically this is to another table
-in DBIC at the moment.
-
-The key field is in OpenERP and is used for the ids of the objects to link to.
-
-The class specifies a link class that is used to follow the link.  These are in
-the namespace OpenERP::OOM::Link.  When class is set to DBIC this means it loads
-OpenERP::OOM::Link::DBIC to follow the link to the DBIC rows.
-
-Possible options for type are C<single> and C<multiple>.
-
-    has_link 'details' => (
-        key   => 'x_dbic_link_id',
-        type  => 'single',
-        class => 'DBIC',
-        args  => {class => 'AuctionHouseDetails'},
-    );
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (C) 2011 OpusVL
-
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-=cut
 
 use 5.010;
 use Carp;
@@ -309,26 +227,6 @@ sub _add_link_single {
         is  => 'ro',
     );
     
-    #$meta->add_method(
-    #    $name,
-    #    sub {
-    #        my $self = shift;
-    #
-    #        # FIXME - this is a bit broken, remembers between different objects!
-    #        # Looks like the method is being added to the whole class, not the individual object
-    #        # Maybe this code needs to go in Base.pm instead, in an "around create{...}" block
-    #        # to add these methods in when a new object is created.
-    #        state $link = $self->class->schema->link($options{class})->retrieve($options{args}, $self->{$options{key}});
-    #    
-    #        $link->meta->make_mutable;
-    #        $link->meta->add_method(
-    #            '_source',
-    #            sub { return $self }
-    #        );
-    #        
-    #        return $link;
-    #    },
-    #);
 }
 
 
@@ -343,16 +241,117 @@ sub _add_link_multiple {
         is  => 'ro',
     );
     
-    #$meta->add_method(
-    #    $name,
-    #    sub {
-    #        my $self = shift;
-    #        return $self->class->schema->link($options{class})->retrieve_list($options{args}, $self->{$options{key}});
-    #    },
-    #);
 }
 
 
 #-------------------------------------------------------------------------------
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+OpenERP::OOM::Object
+
+=head1 VERSION
+
+version 0.43
+
+=head1 SYNOPSIS
+
+    package Package::OpenERP::Object::Account;
+
+    use 5.010;
+    use OpenERP::OOM::Object;
+
+    openerp_model 'account.account';
+
+    has active => (is => 'rw', isa => 'Bool'); # Active
+    has code => (is => 'rw', isa => 'Str'); # (required) Code
+
+    ...
+
+    relationship 'consolidated_children' => (
+        key   => 'child_consol_ids',
+        type  => 'many2many',
+        class => 'Account',
+    ); # Consolidated Children
+
+    ...
+
+    1;
+
+=head1 DESCRIPTION
+
+Use this module to create the 'objects' for your models.  It also implicitly loads
+Moose too.  
+
+The class is linked to a model in OpenERP.
+
+=head1 NAME
+
+OpenERP::OOM::Object
+
+=head1 METHODS
+
+=head2 openerp_model
+
+Specify the model in OpenERP.
+
+=head2 init_meta
+
+An internal method that hooks up the Moose internals and implicitly makes your
+new classes inherit from OpenERP::OOM::Object::Base.  See the 
+OpenERP::OOM::Object::Base documentation for a list of the methods your objects
+will have by default.
+
+=head2 relationship
+
+Used to specify relationships between this object and others in OpenERP.
+
+Possible options for the type are many2one, one2many and many2many.  These
+are specified in OpenERP in those terms.
+
+=head2 has_link
+
+Used to indicate links with other systems.  Typically this is to another table
+in DBIC at the moment.
+
+The key field is in OpenERP and is used for the ids of the objects to link to.
+
+The class specifies a link class that is used to follow the link.  These are in
+the namespace OpenERP::OOM::Link.  When class is set to DBIC this means it loads
+OpenERP::OOM::Link::DBIC to follow the link to the DBIC rows.
+
+Possible options for type are C<single> and C<multiple>.
+
+    has_link 'details' => (
+        key   => 'x_dbic_link_id',
+        type  => 'single',
+        class => 'DBIC',
+        args  => {class => 'AuctionHouseDetails'},
+    );
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright (C) 2011 OpusVL
+
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
+=head1 AUTHOR
+
+Jon Allen (JJ), <jj@opusvl.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011-2016 by OpusVL.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
