@@ -1,11 +1,19 @@
 1;
 package OpenERP::OOM::Tutorial::Schema;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-OpenERP::OOM::Tutorial::Schema - Setting up an OpenERP::OOM Schema
+OpenERP::OOM::Tutorial::Schema
+
+=head1 VERSION
+
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -109,16 +117,21 @@ Objects are created and retrieved from the class:
         say $partner->name;
     }
 
-=head2 AUTHOR
+__END__
 
-Jon Allen (JJ) <jj@opusvl.com>
+=head1 NAME
 
-=head1 COPYRIGHT & LICENSE
+OpenERP::OOM::Tutorial::Schema - Setting up an OpenERP::OOM Schema
 
-Copyright (C) 2012 OpusVL
+=head1 AUTHOR
 
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Jon Allen (JJ), <jj@opusvl.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011-2016 by OpusVL.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
