@@ -2,14 +2,29 @@ package OpenERP::OOM::Tutorial::Searching;
 
 # FIXME: should this be a pod file instead?
 
+
+1;
+
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 OpenERP::OOM::Tutorial::Searching
 
+=head1 VERSION
+
+version 0.43
+
 =head1 DESCRIPTION
 
+=head1 NAME
+
+OpenERP::OOM::Tutorial::Searching
+
 =head1 Complex Search Terms
 
 OpenERP allows logic operators like most database wrappers, just
@@ -24,16 +39,15 @@ to or things together.  You can also use '&' as an operator.
 
 For more details see the OpenERP Developer book.  
 
-=head2 AUTHOR
+=head1 AUTHOR
 
-Colin Newell <colin@opusvl.com>
+Jon Allen (JJ), <jj@opusvl.com>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 OpusVL
+This software is copyright (c) 2011-2016 by OpusVL.
 
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
